@@ -7,6 +7,7 @@
 # Revision     Date                        Release Comment
 # --------  ----------  --------------------------------------------------------------
 #   1.0     7/23/2019   Initial Release
+#   1.1     8/23/2019   Including Docstrings for Constructor and Methods.
 #
 # File Description
 # ----------------
@@ -18,12 +19,27 @@
 #    Name                                     Description
 # ----------                  --------------------------------------------------------
 # __init__()                  Constructor
-# get_lead()                  Returns details of a single Unbounce lead.
+# get_lead()                  Returns details of a single Unbounce Lead.
 #*************************************************************************************
 # Imported Packages:
 import requests
 
 class Lead(object):
+    """A sub-class to Unbounce that contains routes for Lead Objects.
+
+    Arguments
+    ---------
+    1. client {class} -- The parent class; Unbounce.
+    
+    Raises
+    ------
+    None
+
+    Returns
+    -------
+    Class -- Instance of Lead.
+    """
+
     # Initializing static variable for Unbounce Lead URL base.
     LEAD_URL_BASE = 'https://api.unbounce.com/leads'
 
@@ -51,7 +67,7 @@ class Lead(object):
     #
     # Description
     # -----------
-    # This method allows users to retrieve a single lead.
+    # This method allows users to retrieve a single Unbounce Lead.
     #
     # RETurn
     #  Type                            Description
@@ -61,9 +77,24 @@ class Lead(object):
     # ------------------------------- Arguments ------------------------------------------
     #        Type               Name                         Description
     # --------------------  ------------  ------------------------------------------------
-    # string                lead_id       The ID for a given lead.
+    # string                lead_id       The ID for a given Unbounce Lead.
     #*************************************************************************************
     def get_lead(self, lead_id):
+        """Allows users to retrieve a single Unbounce Lead.
+
+        Arguments
+        ---------
+        1. lead_id {string} -- The ID for a given Unbounce Lead.
+
+        Raises
+        ------
+        None
+
+        Returns
+        -------
+        JSON -- The Response object received from the Unbounce server.
+        """
+
         url = self.LEAD_URL_BASE + '/{0}'.format(lead_id)
         # Return the result of the client (Parent) class get() method, pass an appropriate URL.
         return self.client.get(url)
